module.exports = function(grunt) {
    require('load-grunt-tasks')(grunt);
    grunt.loadNpmTasks('grunt-execute');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-copy');

    var values = require('object.values');

    if(!Object.values) {
        values.shim();
    }

    let browser = grunt.option('browser');
    let buildType = grunt.option('type');

    if(!(browser && buildType)) {
        console.error("Missing browser or  build type: --browser=<browser-name> --type=<dev,release>");
        process.exit(1);
    }

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),
        dirs: {
            src: {
                js: 'src/betafish'
            },
            ddgsrc: {
                js: 'src/ddg'
            }
        },
        browserify: {
            options: {
                browserifyOptions: {
                    debug: buildType === 'dev'
                }
            },
            background: {
                src: [ 'src/betafish/ddg-imports.js',
                       'src/ddg/*.es6.js',
                       'src/ddg/classes/*.es6.js',
                       'src/ddg/storage/*.es6.js'],
                dest: 'build/chrome/dev/ddg-background.js'
            },
        },
        clean : {
          options: {
            'force': true
          },
          src : [ `build/${browser}/`]
        },
        copy: {
          main: {
            expand: true,
            cwd: 'src/betafish/',
            src: '**',
            dest: `build/${browser}/${buildType}/`,
          },
        },
        execute: {
            preProcessLists: {
                src: ['scripts/buildEntityMap.js']
            }
        },
        exec: {
            copyEntityMap: `cp shared/data/tracker_lists/entityMap.json build/chrome/dev/`,
        }
    })

    grunt.registerTask('setupBuildDir', 'setup the build dir.', function() {
      grunt.file.mkdir(`build/${browser}`);
      grunt.file.mkdir(`build/${browser}/${buildType}`);
    });

    grunt.registerTask('build', 'Build project css, templates, js', [ 'clean', 'setupBuildDir', 'execute:preProcessLists', 'exec:copyEntityMap', 'browserify:background', 'copy']);

    const devTasks = ['build'];

    grunt.registerTask('dev', 'Build and optionally watch files for development', devTasks);
    grunt.registerTask('default', 'build');
}
